/*
 * Copyright © 2013. Palomino Labs (http://palominolabs.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.palominolabs.crm.sf.soap;

import javax.annotation.Nonnull;
import javax.annotation.concurrent.NotThreadSafe;

/**
 * Used to bundle a binding along with the config data used to configure it so that logging can know which endpoint, etc
 * is in use.
 *
 * @param <B> the type of binding contained
 */
@NotThreadSafe
final class ConfiguredBinding<B> {
    @Nonnull
    private final BindingConfig bindingConfig;
    @Nonnull
    private final B binding;

    ConfiguredBinding(@Nonnull B binding, @Nonnull BindingConfig bindingConfig) {
        this.binding = binding;
        this.bindingConfig = bindingConfig;
    }

    @Nonnull
    B getBinding() {
        return this.binding;
    }

    @Nonnull
    BindingConfig getBindingConfig() {
        return this.bindingConfig;
    }
}
